@@ -1,10 +1,11 @@
-from django.forms import ModelForm, RegexField, ModelChoiceField
 from django.contrib.auth.models import Group
 from samklang_pages.models import Page
 from django.utils.translation import ugettext_lazy as _
+from samklang_utils.forms import MarkdownTextarea#, GroupField
+import floppyforms as forms
 
-class PageForm(ModelForm):
-    url = RegexField(
+class PageForm(forms.ModelForm):
+    url = forms.RegexField(
             label=_("URL"),
             max_length=100,
             regex=r'^[-\w/]+$',
@@ -13,8 +14,10 @@ class PageForm(ModelForm):
             error_message = _("This value must contain only letters, numbers,"
                 " underscores, dashes or slashes."),
             )
-    group = ModelChoiceField(Group.objects, empty_label=_("Public"), required=False, label=_("Read permission"))
+    group = forms.ModelChoiceField(Group.objects, empty_label=_("Public"), required=False, label=_("Read permission"))
+    #group = GroupField(Group.objects, initial='0')
 
     class Meta:
         model = Page
-        exclude = ('content_html', 'user', 'site')
+        fields = ('content', 'url', 'name', 'group', 'admingroup')
+        widgets = {'content': MarkdownTextarea()}
